@@ -18,6 +18,42 @@ class TestForMissingProperties(unittest.TestCase):
         # are added to the response files
 
         ignore = [
+            # general - not yet used
+            'device.messages.info.raw',
+            'device.messages.service.raw',
+            'device.messages.status.raw',
+            'device.parameterIdentification.version',
+
+            'device.configuration.houseLocation',
+            'device.lock.malfunction',
+            'device.timeseries.burner.stops',
+            'device.timeseries.dhw.burner.stops',
+            'device.timeseries.ignitionTimeSteps',
+            'device.timeseries.monitoringIonization',
+            'device.timeseries.water.pressure.peaks',
+            'device.zigbee.active',
+            'device.zigbee.status',
+            'heating.boiler.pumps.internal',
+            'heating.boiler.pumps.internal.target',
+            'heating.burners.0.demand.temperature',
+            'heating.calculated.temperature.outside',
+            'heating.circuits.0.configuration.summerEco.absolute',
+            'heating.configuration.bufferCylinderSize',
+            'heating.configuration.centralHeatingCylinderSize',
+            'heating.configuration.dhwCylinderPump',
+            'heating.configuration.dhwCylinderSize',
+            'device.messages.info.raw',
+            'heating.configuration.gasType',
+            'heating.configuration.houseHeatingLoad',
+            'heating.configuration.houseLocation',
+            'heating.configuration.houseOrientation',
+            'heating.configuration.internalPumps',
+            'heating.configuration.pressure.total',
+            'heating.dhw.scaldProtection',
+            'heating.heat.production.summary.dhw',
+            'heating.heat.production.summary.heating',
+
+            # heating ignored for now
             'heating.operating.programs.holidayAtHome',
             'heating.operating.programs.holiday',
             'heating.device.time.offset',
@@ -25,6 +61,8 @@ class TestForMissingProperties(unittest.TestCase):
             'heating.boiler.temperature',  # ignore as value is to low to be plausible in response data
             'heating.boiler.airflaps.0.position.current',
             'heating.boiler.airflaps.1.position.current',
+            'heating.boiler.pumps.internal',
+            'heating.boiler.pumps.internal.target',
 
             'heating.circuits.0.dhw.pumps.circulation.schedule',
             'heating.circuits.0.dhw.schedule',
@@ -67,11 +105,20 @@ class TestForMissingProperties(unittest.TestCase):
             'heating.burner', # deprecated FIXME: remove once test data is updated
 
             # Ignored for now as they are not documented in https://documentation.viessmann.com/static/iot/data-points
+            'device.configuration.houseLocation',
+            'device.lock.malfunction',
             'device.messages.errors.raw',
             'device.name',
             'device.power.battery',
             'device.productIdentification',
             'device.productMatrix',
+            'device.timeseries.burner.stops',
+            'device.timeseries.dhw.burner.stops',
+            'device.timeseries.ignitionTimeSteps',
+            'device.timeseries.monitoringIonization',
+            'device.timeseries.water.pressure.peaks',
+            'device.zigbee.active',
+            'device.zigbee.status',
             'heating.device.variant',
             'device.time.daylightSaving',
             'heating.device.software',
@@ -99,6 +146,24 @@ class TestForMissingProperties(unittest.TestCase):
             'heating.scop.heating', # deprecated
             'heating.scop.total', # deprecated
             'heating.dhw.comfort', # deprecated
+
+            # energy system - not yet used
+            'device.etn',
+            'device.serial.internalComponents',
+            'ess.battery.usedAverage',
+            'ess.configuration.backupBox',
+            'ess.configuration.systemType',
+            'ess.inverter.ac.power',
+            'ess.sensors.temperature.ambient',
+            'ess.version.hardware',
+            'heating.device.mainECU',
+            'pcc.ac.active.current',
+            'pcc.ac.active.power',
+            'pcc.ac.reactive.power',
+            'pcc.state.gridCode',
+            'photovoltaic.installedPeakPower',
+            'photovoltaic.string.current',
+            'photovoltaic.string.voltage',
         ]
 
         all_features = self.read_all_features()
